@@ -226,6 +226,11 @@ class MSTPDirector(asyncore.dispatcher, Server, ServiceAccessPoint):
         maxinfo = self.localDevice._maxinfo
         buf = struct.pack('iiii', mac, max_masters, baud_rate, maxinfo);
 
+        if hasattr(self.localDevice, '_mstpdbgfile'):
+            fname = self.localDevice._mstpdbgfile
+            mstp_lib.enable_debug_flag(fname)
+
+
         mstp_lib.init(buf, interface_devname, mstp_dir)
 
         # to ensure that the server is ready
